# Security Policy

## Supported Versions

Which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 1.22.x  | ☑️                 |

This page will be updated for the Alpha release to maturity.

## Disclosure

All known security vulnerabilities must be disclosed publically within 30 days of a detection during regular monitoring.

## Reporting a Vulnerability

A security vulnerability must never be posted in Issues.
This must be done directly through GitHub or via help@oziproject.dev

